@@ -6,7 +6,7 @@ from fsu.internal.error import FieldNotExist, ObjectNotExist, UnsupportedOperato
 from fsu.internal.schema import ReadMany, ReadOne, UpdateMany, UpdateOne, DeleteMany, DeleteOne, CreateOne, \
                                 LoginIn, LoginOut, GetCurrentUserOut
 import fsu.internal.error_code as E
-from fsu.security import sign_required, auth_required, jwt_token_required
+from fsu.security import sign_required, jwt_field_required, get_jwt_info
 from fsu.wxwork import get_user_by_code
 from fsu.sql import make_mapper, verbose_where
 from fsu.error import handle_universal_logic_error, UniversalLogicError
@@ -34,7 +34,7 @@ def make_admin_app(
     if not debug:
         app.middleware("http")(sign_required(ttl=60, get_secret_by_uaid=get_secret_by_uaid))
 
-    auth_required_ = auth_required(jwt_secret)
+    admin_required = jwt_field_required("admin_id", jwt_secret)
 
     @app.post("/login", response_model=OK[LoginOut])
     async def login(
@@ -67,8 +67,8 @@ def make_admin_app(
         return OK(data=LoginOut(access_token=token))
 
     @app.get("/user", response_model=OK[GetCurrentUserOut])
-    @auth_required_
-    async def get_current_user(info = Depends(jwt_token_required(jwt_secret)), db = Depends(get_db)):
+    @admin_required
+    async def get_current_user(info = Depends(get_jwt_info(jwt_secret)), db = Depends(get_db)):
         admin_id = info.get("admin_id")
 
         if admin_id is None:
@@ -85,12 +85,12 @@ def make_admin_app(
         return OK(data=mapper.dict(row))
 
     @app.get("/enums")
-    @auth_required_
+    @admin_required
     async def get_enums():
         return OK(data=enums)
 
     @app.post("/read")
-    @auth_required_
+    @admin_required
     async def read_many(i : ReadMany, db : Database = Depends(get_db)):
         try:
             mapper = make_mapper(i.object, metadata, i.fields_)
@@ -119,7 +119,7 @@ def make_admin_app(
         return OK(data=data, total=total)
 
     @app.post("/read/{id}")
-    @auth_required_
+    @admin_required
     async def read_one(id : int, i : ReadOne, db : Database = Depends(get_db)):
         try:
             mapper = make_mapper(i.object, metadata, i.fields_)
@@ -139,7 +139,7 @@ def make_admin_app(
         return OK(data=data)
 
     @app.post("/create")
-    @auth_required_
+    @admin_required
     async def create_one(i : CreateOne, db : Database = Depends(get_db)):
         if i.object not in tables:
             raise HTTPException(422, f"object `{i.object}` not exist")
@@ -156,7 +156,7 @@ def make_admin_app(
         return OK()
 
     @app.post("/update")
-    @auth_required_
+    @admin_required
     async def update_many(i : UpdateMany, db : Database = Depends(get_db)):
         try:
             where_clause = verbose_where(i.object, metadata, i.filter)
@@ -176,7 +176,7 @@ def make_admin_app(
         return OK(data=ret)
 
     @app.post("/update/{id}")
-    @auth_required_
+    @admin_required
     async def update_one(id : int, i : UpdateOne, db : Database = Depends(get_db)):
         if i.object not in tables:
             raise HTTPException(422, f"object `{i.object}` not exist")
@@ -193,7 +193,7 @@ def make_admin_app(
         return OK()
 
     @app.post("/delete")
-    @auth_required_
+    @admin_required
     async def delete_many(i : DeleteMany, db : Database = Depends(get_db)):
         try:
             where_clause = verbose_where(i.object, metadata, i.filter)
@@ -213,7 +213,7 @@ def make_admin_app(
         return OK(data=ret)
 
     @app.post("/delete/{id}")
-    @auth_required_
+    @admin_required
     async def delete_one(id : int, i : DeleteOne, db : Database = Depends(get_db)):
         if i.object not in tables:
             raise HTTPException(422, f"object `{i.object}` not exist")
